@@ -77,10 +77,10 @@ update_indention_ref_fun_dec <- function(pd_nested) {
 #' @keywords internal
 apply_ref_indention <- function(flattened_pd) {
   target_tokens <- which(flattened_pd$pos_id %in% flattened_pd$indention_ref_pos_id)
-  flattened_pd <- reduce(
-    target_tokens,
+  flattened_pd <- Reduce(
     apply_ref_indention_one,
-    .init = flattened_pd
+    target_tokens,
+    init = flattened_pd
   )
   flattened_pd
 }
@@ -178,5 +178,5 @@ set_regex_indention <- function(flattened_pd,
 
   to_check$lag_spaces[indices_to_force] <- target_indention
   bind_rows(to_check, not_to_check) %>%
-    arrange(pos_id)
+    arrange_pos_id()
 }
