@@ -51,13 +51,19 @@ set_space_around_op <- function(pd_flat, strict) {
 style_space_around_math_token <- function(strict, zero, one, pd_flat) {
   # We remove spaces for zero (e.g., around ^ in the tidyverse style guide)
   # even for strict = FALSE to be consistent with the : operator
-  pd_flat %>%
-    style_space_around_token(
-      strict = TRUE, tokens = zero, level_before = 0L, level_after = 0L
-    ) %>%
-    style_space_around_token(
-      strict = strict, tokens = one, level_before = 1L, level_after = 1L
-    )
+  if (any(pd_flat$token %in% zero)) {
+    pd_flat <- pd_flat %>%
+      style_space_around_token(
+        strict = TRUE, tokens = zero, level_before = 0L, level_after = 0L
+      )
+  }
+  if (any(pd_flat$token %in% one)) {
+    pd_flat <- pd_flat %>%
+      style_space_around_token(
+        strict = strict, tokens = one, level_before = 1L, level_after = 1L
+      )
+  }
+  pd_flat
 }
 
 #' Set spacing of token to a certain level
@@ -165,7 +171,7 @@ remove_space_before_opening_paren <- function(pd_flat) {
 }
 
 remove_space_after_opening_paren <- function(pd_flat) {
-  paren_after <- pd_flat$token == "'('"
+  paren_after <- pd_flat$token %in% c("'('", "'['", "LBB")
   if (!any(paren_after)) {
     return(pd_flat)
   }
@@ -174,7 +180,7 @@ remove_space_after_opening_paren <- function(pd_flat) {
 }
 
 remove_space_before_closing_paren <- function(pd_flat) {
-  paren_after <- pd_flat$token == "')'"
+  paren_after <- pd_flat$token %in% c("')'", "']'")
   if (!any(paren_after)) {
     return(pd_flat)
   }
