@@ -24,7 +24,6 @@ text <- c(
   rep(10)
 
 capture.output(test_that("activated cache brings speedup on style_text() API on character vector", {
-
   activate_testthat_cache()
   on.exit(clear_testthat_cache())
   clear_testthat_cache()
@@ -36,7 +35,6 @@ capture.output(test_that("activated cache brings speedup on style_text() API on
 }))
 
 capture.output(test_that("activated cache brings speedup on style_text() API on character scalar", {
-
   activate_testthat_cache()
   on.exit(clear_testthat_cache())
   clear_testthat_cache()
@@ -48,8 +46,45 @@ capture.output(test_that("activated cache brings speedup on style_text() API on
 }))
 
 
-capture.output(test_that("no speedup when tranformer changes", {
+test_that("trailing line breaks are ignored for caching", {
+  on.exit(clear_testthat_cache())
+  clear_testthat_cache()
+  activate_testthat_cache()
 
+  first <- system.time(styler::style_text(paste0(text, collapse = "\n")))
+  second <- system.time(
+    styler::style_text(c(paste0(text, collapse = "\n"), "\n", "\n", "\n", "\n"))
+  )
+  expect_true(first["elapsed"] / 2 > second["elapsed"])
+  # check we only have three different expressions. Top-level, example and fun.
+  cache_info <- cache_info()
+  expect_equal(
+    cache_info$n,
+    3
+  )
+})
+
+test_that("trailing line breaks are ignored for caching in one scalar", {
+  on.exit(clear_testthat_cache())
+  clear_testthat_cache()
+  activate_testthat_cache()
+
+  first <- system.time(styler::style_text(paste0(text, collapse = "\n")))
+  second <- system.time(
+    styler::style_text(
+      paste0(paste0(text, collapse = "\n"), "\n", "\n", "\n", "\n", collapse = "")
+    )
+  )
+  expect_true(first["elapsed"] / 2 > second["elapsed"])
+  # check we only have three different expressions. Top-level, example and fun.
+  cache_info <- cache_info()
+  expect_equal(
+    cache_info$n,
+    3
+  )
+})
+
+capture.output(test_that("no speedup when tranformer changes", {
   activate_testthat_cache()
   on.exit(clear_testthat_cache())
   clear_testthat_cache()
@@ -75,11 +110,11 @@ capture.output(
     first <- system.time(styler::style_text(text))
     second <- system.time(styler::style_text(paste0(text, collapse = "\n")))
     expect_true(first["elapsed"] / 2 > second["elapsed"])
-  }))
+  })
+)
 
 
 capture.output(test_that("unactivated cache does not bring speedup", {
-
   on.exit(clear_testthat_cache())
   clear_testthat_cache()
   cache_deactivate()
@@ -90,7 +125,6 @@ capture.output(test_that("unactivated cache does not bring speedup", {
 
 
 capture.output(test_that("avoid deleting comments #584 (see commit messages)", {
-
   on.exit(clear_testthat_cache())
   clear_testthat_cache()
   activate_testthat_cache()
@@ -99,7 +133,7 @@ capture.output(test_that("avoid deleting comments #584 (see commit messages)", {
     "# Comment",
     "# another",
     "NULL"
-    )
+  )
   style_text(text)
   text2 <- c(
     "1 + 1",
@@ -115,7 +149,6 @@ capture.output(test_that("avoid deleting comments #584 (see commit messages)", {
 
 
 capture.output(test_that("avoid removing roxygen mask (see commit messages in #584)", {
-
   on.exit(clear_testthat_cache())
   clear_testthat_cache()
   activate_testthat_cache()
@@ -142,3 +175,26 @@ capture.output(test_that("avoid removing roxygen mask (see commit messages in #5
     text2
   )
 }))
+
+
+capture.output(test_that("partial caching of multiple expressions on one line works", {
+  on.exit(clear_testthat_cache())
+  clear_testthat_cache()
+  activate_testthat_cache()
+  text <- "1"
+  style_text(text)
+  text2 <- "1 # comment"
+  styled <- style_text(text2)
+  expect_equal(
+    as.character(styled),
+    text2
+  )
+
+  style_text("mtcars")
+  style_text(c("mtcars %>%", "f()"))
+  final_text <- c("mtcars %>%", "  f() #")
+  expect_equal(
+    as.character(style_text(final_text)),
+    final_text
+  )
+}))
