@@ -9,6 +9,35 @@ test_that("styler can style package", {
   }))
 })
 
+test_that("styler can style package and exclude some directories", {
+  capture_output(expect_true({
+    styled <- style_pkg(testthat_file("public-api", "xyzpackage"),
+        exclude_dirs = "tests"
+    )
+    nrow(styled) == 1
+  }))
+})
+
+
+test_that("styler can style package and exclude some directories and files", {
+  capture_output(expect_true({
+    styled <- style_pkg(testthat_file("public-api", "xyzpackage"),
+                        exclude_dirs = "tests",
+                        exclude_files = ".Rprofile"
+    )
+    nrow(styled) == 1
+  }))
+
+  capture_output(expect_true({
+    styled <- style_pkg(testthat_file("public-api", "xyzpackage"),
+                        exclude_dirs = "tests",
+                        exclude_files = "./.Rprofile"
+    )
+    nrow(styled) == 1
+  }))
+})
+
+
 test_that("styler can style directory", {
   capture_output(expect_false({
     styled <- style_dir(testthat_file("public-api", "xyzdir"))
@@ -16,6 +45,47 @@ test_that("styler can style directory", {
   }))
 })
 
+test_that("styler can style directories and exclude", {
+  capture_output(expect_true({
+    styled <- style_dir(
+      testthat_file("public-api", "renvpkg"),
+      exclude_dirs = "renv"
+    )
+    nrow(styled) == 2
+  }))
+  capture_output(expect_true({
+    styled <- style_dir(
+      testthat_file("public-api", "renvpkg"),
+      exclude_dirs = c("renv", "tests/testthat")
+    )
+    nrow(styled) == 1
+  }))
+
+  capture_output(expect_true({
+    styled <- style_dir(
+      testthat_file("public-api", "renvpkg"),
+      exclude_dirs = "./renv"
+    )
+    nrow(styled) == 2
+  }))
+
+  capture_output(expect_true({
+    styled <- style_dir(
+      testthat_file("public-api", "renvpkg"),
+      exclude_dirs = "./renv", recursive = FALSE
+    )
+    nrow(styled) == 0
+  }))
+
+  capture_output(expect_true({
+    styled <- style_dir(
+      testthat_file("public-api", "renvpkg"),
+      recursive = FALSE
+    )
+    nrow(styled) == 0
+  }))
+})
+
 test_that("styler can style files", {
   # just one
   capture_output(expect_equivalent(
